package component

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Clear
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material.icons.filled.Search
import androidx.compose.material.icons.outlined.Info
import androidx.compose.material.icons.outlined.Settings
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.semantics.isTraversalGroup
import androidx.compose.ui.semantics.semantics
import androidx.compose.ui.semantics.traversalIndex
import androidx.compose.ui.unit.dp
import cafe.adriel.voyager.navigator.LocalNavigator
import cafe.adriel.voyager.navigator.currentOrThrow
import org.jetbrains.compose.resources.painterResource
import tab.About
import tab.Licenses
import tab.setting.Settings
import veganenumbers.composeapp.generated.resources.Res
import veganenumbers.composeapp.generated.resources.handshake_24px

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Search(text: MutableState<String>) {
    var expanded by rememberSaveable { mutableStateOf(false) }
    val menuExpanded = remember { mutableStateOf(false) }

    Column (
        Modifier
            .fillMaxWidth()
            .padding(if (!expanded) 8.dp else 0.dp)
            .semantics { isTraversalGroup = true }
    ) {
        SearchBar(
            modifier = Modifier
                .align(Alignment.CenterHorizontally)
                .semantics { traversalIndex = 0f },
            query = text.value,
            onQueryChange = { text.value = it },
            onSearch = { expanded = false },
            onActiveChange = { /* Do nothing */ },
            active = expanded,
            placeholder = { Text("Search E Numbers") },
            leadingIcon = {
                IconButton(
                    enabled = false,
                    onClick = { /* Do nothing */ }
                ) {
                    Icon(Icons.Filled.Search, "Navigation Menu")
                }
            },
            trailingIcon = {
                Row {
                    if (text.value.isNotEmpty()) {
                        IconButton(onClick = { text.value = "" }) {
                            Icon(imageVector = Icons.Filled.Clear, contentDescription = "Clear Search")
                        }
                    }
                    if (!expanded) {
                        IconButton(onClick = { menuExpanded.value = !menuExpanded.value }) {
                            Icon(imageVector = Icons.Filled.MoreVert, contentDescription = "Dropdown Menu")
                        }
                        OptionsMenu(menuExpanded)
                    }
                }
            }
        ) { /* No search content - done externally */ }
    }
}

@Composable
private fun OptionsMenu(expanded: MutableState<Boolean>) {
    val navigator = LocalNavigator.currentOrThrow

    DropdownMenu(
        expanded = expanded.value,
        onDismissRequest = { expanded.value = false },
    ) {
        DropdownMenuItem(
            text = { Text("Settings") },
            onClick = { navigator.push(Settings) },
            leadingIcon = { Icon(imageVector = Icons.Outlined.Settings, contentDescription = "Open settings") }
        )
        DropdownMenuItem(
            text = { Text("About") },
            onClick = { navigator.push(About) },
            leadingIcon = { Icon(imageVector = Icons.Outlined.Info, contentDescription = "Information about the application") }
        )
        DropdownMenuItem(
            text = { Text("Licenses") },
            onClick = { navigator.push(Licenses) },
            leadingIcon = { Icon(painter = painterResource(Res.drawable.handshake_24px), contentDescription = "Information about Licenses") }
        )
    }
}
