package tab.setting

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.input.nestedscroll.nestedScroll
import cafe.adriel.voyager.core.screen.Screen
import cafe.adriel.voyager.navigator.LocalNavigator
import cafe.adriel.voyager.navigator.currentOrThrow
import data.SettingsVar

object Settings : Screen {

    @OptIn(ExperimentalMaterial3Api::class)
    @Composable
    override fun Content() {
        val navigator = LocalNavigator.currentOrThrow
        val scrollBehavior = TopAppBarDefaults.pinnedScrollBehavior(rememberTopAppBarState())

        Scaffold (
            modifier = Modifier.nestedScroll(scrollBehavior.nestedScrollConnection),
            topBar = {
                TopAppBar(
                    title = { Text("Settings") },
                    navigationIcon = {
                        IconButton(onClick = { navigator.pop() }) {
                            Icon(imageVector = Icons.AutoMirrored.Filled.ArrowBack, contentDescription = "Go back to main app")
                        }
                    },
                    scrollBehavior = scrollBehavior
                )
            },
        ) {
            Column (modifier = Modifier.padding(it)) {
                SettingsContent()
            }
        }
    }

    @Composable
    private fun SettingsContent() {
        Theme()
        Text("List Style")
    }

    /**
     * ALl the different themes that can be picked
     * - 0 - Auto
     * - 1 - Light
     * - 2 - Dark
     */
    @Composable
    private fun Theme() {
        var mode by rememberSaveable { SettingsVar.theme }
        val themes = listOf("Auto", "Light", "Dark")

        Text("Theme")

        for ((index, value) in themes.withIndex()) {
            Row(
                verticalAlignment = Alignment.CenterVertically,
            ) {
                RadioButton(
                    selected = mode == index,
                    onClick = { mode = index }
                )
                Text(value)
            }
        }
    }
}
